<?php
/*
Plugin Name: mjmarks
Plugin URI:
Description: Replace Mah-jong expressions to the Mah-jong tile images. 
Version: 1.0.1
Author: Kei Saito
Author URI:
*/

/*  Copyright 2007 Kei Saito (email : kei.saito@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*

 This filter plugin replaces Mah-jong expressions in the
 contents and comments into Mah-jong tile images. 

 Supported expressions are following:
 [1p], [2p], ...[9p] : 1-9 dots (pin-zu)
 [1s], [2s], ...[9s] : 1-9 bamboos (so-zu)
 [1m], [2m], ...[9m] : 1-9 characters (man-zu)
 [5pr], [5sr], [5mr] : red 5's (aka-wo)
 [ton]               : East  (ton)
 [nan]               : South (nan)
 [sha]               : West  (sha)
 [pei]               : North (pei)
 [hak]               : White (haku)
 [hat]               : Green (hatsu)
 [chu]               : Red   (chun)
 [ura]               : Backside (ura)

 Adding 'l' after the expression shows the 90-degree-rotated image.
 For example, [1pl] shows rotated [1p] image. 

 You can escape the expression by adding another braces
 like [[1p]]. 

 Images are the royality-free from : 
 http://www4.cty-net.ne.jp/~l6000all/haigapage.htm
*/

function filter_mjmarks($content) {

  // handling escapes, temporariry renaming [[xx]] expressions to ___xx____
  $pattern = '/\[{2}(\d(m|p|s)r{0,1}l{0,1})\]{2}/';
  $replacement = '___${1}___';
  $content = preg_replace($pattern, $replacement, $content);

  // handling escapes, temporariry renaming [[xx]] expressions to ___xx____
  $pattern = '/\[{2}((ton|nan|sha|pei|hak|hat|chu|ura)l{0,1})\]{2}/';
  $replacement = '___${1}___';
  $content = preg_replace($pattern, $replacement, $content);


  // replace numbers
  $pattern = '/\[(\d(m|p|s)r{0,1}l{0,1})\]/';
  $replacement = '<img src="wp-content/plugins/mjmarks/images/${1}.gif"/>';
  $content = preg_replace($pattern, $replacement, $content);

  // replace characters
  $pattern = '/\[((ton|nan|sha|pei|hak|hat|chu|ura)l{0,1})]/';
  $replacement = '<img src="wp-content/plugins/mjmarks/images/${1}.gif"/>';
  $content = preg_replace($pattern, $replacement, $content);


  // handling escapes, get back ___xx____ expressions to [xx]
  $pattern = '/___(\d(m|p|s)r{0,1}l{0,1})___/';
  $replacement = '[${1}]';
  $content = preg_replace($pattern, $replacement, $content);

  // handling escapes, get back ___xx____ expressions to [xx]
  $pattern = '/___((ton|nan|sha|pei|hak|hat|chu|ura)l{0,1})___/';
  $replacement = '[${1}]';
  $content = preg_replace($pattern, $replacement, $content);

  return $content;
}
add_filter('the_content', 'filter_mjmarks');
add_filter('comment_text', 'filter_mjmarks');
?>